@@ -1,6 +1,8 @@
 import json
 import logging
+from functools import partial
 from pathlib import Path
+from tempfile import TemporaryDirectory
 from typing import Callable, List
 
 from gitignore_parser import rule_from_pattern
@@ -9,6 +11,7 @@ from potodo.arguments_handling import parse_args
 from potodo.forge_api import get_issue_reservations
 from potodo.json import json_dateconv
 from potodo.logging import setup_logging
+from potodo.merge import sync_po_and_pot
 from potodo.po_file import PoFileStats, PoProjectStats
 
 
@@ -44,14 +47,19 @@ def scan_path(
     return po_project
 
 
-def print_matching_files(po_project: PoProjectStats) -> None:
+def print_matching_files(po_project: PoProjectStats, show_finished: bool) -> None:
     for directory_stats in sorted(po_project.stats_by_directory()):
         for file_stat in sorted(directory_stats.files_stats):
+            if not show_finished and file_stat.percent_translated == 100:
+                continue
             print(file_stat.path)
 
 
 def print_po_project(
-    po_project: PoProjectStats, counts: bool, show_reservation_dates: bool
+    po_project: PoProjectStats,
+    counts: bool,
+    show_reservation_dates: bool,
+    show_finished: bool,
 ) -> None:
     for directory_stats in sorted(po_project.stats_by_directory()):
         print(
@@ -59,6 +67,8 @@ def print_po_project(
         )
 
         for file_stat in sorted(directory_stats.files_stats):
+            if not show_finished and file_stat.percent_translated == 100:
+                continue
             line = f"- {file_stat.filename:<30} "
             if counts:
                 line += f"{file_stat.missing:3d} to do"
@@ -75,7 +85,7 @@ def print_po_project(
         print(f"\n\n# TOTAL ({po_project.completion:.2f}% done)\n")
 
 
-def print_po_project_as_json(po_project: PoProjectStats) -> None:
+def print_po_project_as_json(po_project: PoProjectStats, show_finished: bool) -> None:
     print(
         json.dumps(
             [
@@ -85,6 +95,7 @@ def print_po_project_as_json(po_project: PoProjectStats) -> None:
                     "files": [
                         po_file.as_dict()
                         for po_file in sorted(directory_stats.files_stats)
+                        if show_finished or po_file.percent_translated < 100
                     ],
                 }
                 for directory_stats in sorted(po_project.stats_by_directory())
@@ -123,7 +134,7 @@ def main() -> None:
 
     ignore_matches = build_ignore_matcher(args.path, args.exclude)
 
-    def select(po_file: PoFileStats) -> bool:
+    def select(ignore_matches: Callable[[str], bool], po_file: PoFileStats) -> bool:
         """Return True if the po_file should be displayed, False otherwise."""
         if ignore_matches(str(po_file.path)):
             return False
@@ -132,8 +143,7 @@ def main() -> None:
         if args.exclude_fuzzy and po_file.fuzzy:
             return False
         if (
-            po_file.percent_translated == 100
-            or po_file.percent_translated < args.above
+            po_file.percent_translated < args.above
             or po_file.percent_translated > args.below
         ):
             return False
@@ -146,18 +156,48 @@ def main() -> None:
 
         return True
 
-    if args.is_interactive:
-        from potodo.interactive import interactive_output
+    if args.pot:
+        with TemporaryDirectory() as tmpdir:
+            po_project = merge_and_scan_path(
+                args.path,
+                Path(args.pot),
+                hide_reserved=args.hide_reserved,
+                api_url=args.api_url,
+                merge_path=Path(tmpdir),
+            )
+            ignore_matches = build_ignore_matcher(Path(tmpdir), args.exclude)
 
-        interactive_output(args.path, ignore_matches)
-        return
+            if args.is_interactive:
+                from potodo.interactive import interactive_output
 
-    po_project = scan_path(args.path, args.no_cache, args.hide_reserved, args.api_url)
-    po_project.filter(select)
-    if args.matching_files:
-        print_matching_files(po_project)
-    elif args.json_format:
-        print_po_project_as_json(po_project)
+                interactive_output(Path(tmpdir), ignore_matches)
+                return
+            po_project.filter(partial(select, ignore_matches))
     else:
-        print_po_project(po_project, args.counts, args.show_reservation_dates)
+        if args.is_interactive:
+            from potodo.interactive import interactive_output
+
+            interactive_output(args.path, ignore_matches)
+            return
+        po_project = scan_path(
+            args.path, args.no_cache, args.hide_reserved, args.api_url
+        )
+        po_project.filter(partial(select, ignore_matches))
+    if args.matching_files:
+        print_matching_files(po_project, args.show_finished)
+    elif args.json_format:
+        print_po_project_as_json(po_project, args.show_finished)
+    else:
+        print_po_project(
+            po_project, args.counts, args.show_reservation_dates, args.show_finished
+        )
     po_project.write_cache()
+
+
+def merge_and_scan_path(
+    path: Path, pot_path: Path, merge_path: Path, hide_reserved: bool, api_url: str
+) -> PoProjectStats:
+    sync_po_and_pot(path, pot_path, merge_path)
+    return scan_path(
+        merge_path, no_cache=True, hide_reserved=hide_reserved, api_url=api_url
+    )
